# CrowdTruth data experiments

[Semeval](https://paperswithcode.com/sota/relation-extraction-on-semeval-2010-task-8) relation extraction dataset.

To see more, go to the [relation_examples.ipynb](https://github.com/adaamko/POTATO/blob/main/notebooks/relation_examples.ipynb) jupyter notebook.

Precomputed graphs can be downloaded running:

```bash
bash data.sh
```

Then the frontend of POTATO can be started from the __frontend__ directory:

```bash
streamlit run app.py -- -t ../features/semeval/semeval_train.tsv -v ../features/semeval/semeval_val.tsv
```